@@ -1,9 +1,9 @@
 /*M*
 //  PVCS:
 //      $Workfile:   imbapi.c  $
-//      $Revision: 1.2 $
+//      $Revision: 1.5 $
 //      $Modtime:   06 Aug 2001 13:16:56  $
-//      $Author: iceblink $
+//      $Author: stybla $
 //
 //  Purpose:    This file contains the entry point that opens the IMB device in
 //              order to issue the  IMB driver API related IOCTLs.
@@ -39,6 +39,21 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *----------------------------------------------------------------------*/
 /*
  * $Log: imbapi.c,v $
+ * Revision 1.5  2013/07/22 08:35:23  stybla
+ * ID: 65 - Fixes for configure.in for cross compilation
+ *
+ * 'src/plugins/imb/imbapi.c' - don't cast NULL to int, ever!!!
+ *
+ * Revision 1.4  2013/07/21 11:33:57  stybla
+ * ID: 65 - Fixes for configure.in for cross compilation
+ *
+ * NULL should never be cast to an int.
+ *
+ * Commit for Dan Gora
+ *
+ * Revision 1.3  2013/01/18 12:46:52  ledva
+ * 3600962 descriptor leaks
+ *
  * Revision 1.2  2004/08/31 23:52:58  iceblink
  * fix lots of little errors that show up with -Werror -Wall
  *
@@ -270,6 +285,7 @@ int open_imb(void)
 			{
 				printf("%s: SendTimedImbpRequest error. Ret = %d CC = 0x%X\n",
 					__FUNCTION__, my_ret_code, completionCode);
+					close(hDevice1);
 					hDevice1 = 0;
 					return (0);
 			}
@@ -1905,7 +1921,7 @@ MapPhysicalMemory (
 	BOOL                 status;
 	PHYSICAL_MEMORY_INFO pmi;
    
-	if ( startAddress == (int) NULL || addressLength <= 0 )
+	if (startAddress == 0 || addressLength <= 0)
 		return ACCESN_OUT_OF_RANGE;
 
 	pmi.InterfaceType       = Internal;
@@ -1967,7 +1983,7 @@ MapPhysicalMemory(int startAddress,int addressLength, int *virtualAddress )
 	unsigned int 		diff;
 	caddr_t 			startvAddress;
 
-	if ((startAddress == (int) NULL) || (addressLength <= 0))
+	if ((startAddress == 0) || (addressLength <= 0))
 		return ACCESN_ERROR;
 
 	if ( (fd = open("/dev/mem", O_RDONLY)) < 0) {
@@ -2016,6 +2032,7 @@ MapPhysicalMemory(int startAddress,int addressLength, int *virtualAddress )
 #endif /*LINUX_DEBUG_MAX */
 
 	*virtualAddress = (long)(startvAddress + diff);
+	close(fd);
 	return ACCESN_OK;
 }
 
