@@ -55,6 +55,7 @@
 #include <ipmitool/ipmi_channel.h>
 #include <ipmitool/ipmi_intf.h>
 #include <ipmitool/ipmi_strings.h>
+#include <ipmitool/hpm2.h>
 #include <ipmitool/bswap.h>
 #include <openssl/rand.h>
 
@@ -65,6 +66,13 @@
 #include "rmcp.h"
 #include "asf.h"
 
+/*
+ * LAN interface is required to support 45 byte request transactions and
+ * 42 byte response transactions.
+ */
+#define IPMI_LAN_MAX_REQUEST_SIZE	38	/* 45 - 7 */
+#define IPMI_LAN_MAX_RESPONSE_SIZE	34	/* 42 - 8 */
+
 extern const struct valstr ipmi_rakp_return_codes[];
 extern const struct valstr ipmi_priv_levels[];
 extern const struct valstr ipmi_auth_algorithms[];
@@ -112,8 +120,10 @@ static int check_sol_packet_for_new_data(
 static void ack_sol_packet(
 							struct ipmi_intf * intf,
 							struct ipmi_rs * rsp);
+static void ipmi_lanp_set_max_rq_data_size(struct ipmi_intf * intf, uint16_t size);
+static void ipmi_lanp_set_max_rp_data_size(struct ipmi_intf * intf, uint16_t size);
 
-static uint8_t bridgePossible = 0; 
+static uint8_t bridgePossible = 0;
 
 struct ipmi_intf ipmi_lanplus_intf = {
 	name:		"lanplus",
@@ -125,6 +135,8 @@ struct ipmi_intf ipmi_lanplus_intf = {
 	recv_sol:	ipmi_lanplus_recv_sol,
 	send_sol:	ipmi_lanplus_send_sol,
 	keepalive:	ipmi_lanplus_keepalive,
+	set_max_request_data_size: ipmi_lanp_set_max_rq_data_size,
+	set_max_response_data_size: ipmi_lanp_set_max_rp_data_size,
 	target_addr:	IPMI_BMC_SLAVE_ADDR,
 };
 
@@ -2099,6 +2111,7 @@ ipmi_lanplus_send_payload(
 	uint8_t             * msg_data;
 	int                   msg_length;
 	struct ipmi_session * session = intf->session;
+	struct ipmi_rq_entry * entry = NULL;
 	int                   try = 0;
 	int                   xmit = 1;
 	time_t                ltime;
@@ -2123,7 +2136,6 @@ ipmi_lanplus_send_payload(
 				/*
 				 * Build an IPMI v1.5 or v2 command
 				 */
-				struct ipmi_rq_entry * entry;
 				struct ipmi_rq * ipmi_request = payload->payload.ipmi_request.request;
 
 				lprintf(LOG_DEBUG, "");
@@ -2174,7 +2186,8 @@ ipmi_lanplus_send_payload(
 			else if (payload->payload_type == IPMI_PAYLOAD_TYPE_RMCP_OPEN_REQUEST)
 			{
 				lprintf(LOG_DEBUG, ">> SENDING AN OPEN SESSION REQUEST\n");
-				assert(session->v2_data.session_state == LANPLUS_STATE_PRESESSION);
+				assert(session->v2_data.session_state == LANPLUS_STATE_PRESESSION
+						|| session->v2_data.session_state == LANPLUS_STATE_OPEN_SESSION_SENT);
 
 				ipmi_lanplus_build_v2x_msg(intf,        /* in  */
 								payload,     /* in  */
@@ -2249,11 +2262,17 @@ ipmi_lanplus_send_payload(
 		{
 		case IPMI_PAYLOAD_TYPE_RMCP_OPEN_REQUEST:
 			session->v2_data.session_state = LANPLUS_STATE_OPEN_SESSION_SENT;
+			/* not retryable for timeouts, force no retry */
+			try = session->retry;
 			break;
 		case IPMI_PAYLOAD_TYPE_RAKP_1:
 			session->v2_data.session_state = LANPLUS_STATE_RAKP_1_SENT;
+			/* not retryable for timeouts, force no retry */
+			try = session->retry;
 			break;
 		case IPMI_PAYLOAD_TYPE_RAKP_3:
+			/* not retryable for timeouts, force no retry */
+			try = session->retry;
 			session->v2_data.session_state = LANPLUS_STATE_RAKP_3_SENT;
 			break;
 		}
@@ -2304,6 +2323,10 @@ ipmi_lanplus_send_payload(
 
 			if (rsp)
 				break;
+			/* This payload type is retryable for timeouts. */
+			if ((payload->payload_type == IPMI_PAYLOAD_TYPE_IPMI) && entry) {
+				ipmi_req_remove_entry( entry->rq_seq, entry->req.msg.cmd);
+			}
 		}
 
 		/* only timeout if time exceeds the timeout value */
@@ -2770,6 +2793,7 @@ ipmi_lanplus_open_session(struct ipmi_intf * intf)
 	struct ipmi_session * session = intf->session;
 	uint8_t * msg;
 	struct ipmi_rs * rsp;
+	/* 0 = success, 1 = error, 2 = timeout */
 	int rc = 0;
 
 
@@ -2779,7 +2803,7 @@ ipmi_lanplus_open_session(struct ipmi_intf * intf)
 	msg = (uint8_t*)malloc(IPMI_OPEN_SESSION_REQUEST_SIZE);
 	if (msg == NULL) {
 		lprintf(LOG_ERR, "ipmitool: malloc failure");
-		return -1;
+		return 1;
 	}
 
 	memset(msg, 0, IPMI_OPEN_SESSION_REQUEST_SIZE);
@@ -2809,7 +2833,7 @@ ipmi_lanplus_open_session(struct ipmi_intf * intf)
 				session->cipher_suite_id);
 		free(msg);
 		msg = NULL;
-		return -1;
+		return 1;
 	}
 
 
@@ -2858,18 +2882,20 @@ ipmi_lanplus_open_session(struct ipmi_intf * intf)
 
 	free(msg);
 	msg = NULL;
-
+	if (rsp == NULL ) {
+		lprintf(LOG_DEBUG, "Timeout in open session response message.");
+		return 2;
+	}
 	if (verbose)
 		lanplus_dump_open_session_response(rsp);
 
-
 	if (rsp->payload.open_session_response.rakp_return_code !=
 		IPMI_RAKP_STATUS_NO_ERRORS)
 	{
 		lprintf(LOG_WARNING, "Error in open session response message : %s\n",
 			val2str(rsp->payload.open_session_response.rakp_return_code,
 				ipmi_rakp_return_codes));
-		return -1;
+		return 1;
 	}
 	else
 	{
@@ -2903,7 +2929,7 @@ ipmi_lanplus_open_session(struct ipmi_intf * intf)
 					"not what we requested 0x%02x\n",
 					rsp->payload.open_session_response.auth_alg,
 					session->v2_data.requested_auth_alg);
-			rc = -1;
+			rc = 1;
 		}
 		else if (rsp->payload.open_session_response.integrity_alg !=
 				 session->v2_data.requested_integrity_alg)
@@ -2912,7 +2938,7 @@ ipmi_lanplus_open_session(struct ipmi_intf * intf)
 					"not what we requested 0x%02x\n",
 					rsp->payload.open_session_response.integrity_alg,
 					session->v2_data.requested_integrity_alg);
-			rc = -1;
+			rc = 1;
 		}
 		else if (rsp->payload.open_session_response.crypt_alg !=
 				 session->v2_data.requested_crypt_alg)
@@ -2921,7 +2947,7 @@ ipmi_lanplus_open_session(struct ipmi_intf * intf)
 					"not what we requested 0x%02x\n",
 					rsp->payload.open_session_response.crypt_alg,
 					session->v2_data.requested_crypt_alg);
-			rc = -1;
+			rc = 1;
 		}
 
 	}
@@ -2955,7 +2981,7 @@ ipmi_lanplus_rakp1(struct ipmi_intf * intf)
 	struct ipmi_session * session = intf->session;
 	uint8_t * msg;
 	struct ipmi_rs * rsp;
-	int rc = 0;
+	int rc = 0;    /* 0 = success, 1 = error, 2 = timeout */
 
 	/*
 	 * Build a RAKP 1 message
@@ -3035,8 +3061,8 @@ ipmi_lanplus_rakp1(struct ipmi_intf * intf)
 
 	if (rsp == NULL)
 	{
-		lprintf(LOG_INFO, "> Error: no response from RAKP 1 message");
-		return 1;
+		lprintf(LOG_WARNING, "> Error: no response from RAKP 1 message");
+		return 2;
 	}
 
 	session->v2_data.session_state = LANPLUS_STATE_RAKP_2_RECEIVED;
@@ -3208,8 +3234,8 @@ ipmi_lanplus_rakp3(struct ipmi_intf * intf)
 	}
 	else if (rsp == NULL)
 	{
-		lprintf(LOG_INFO, "> Error: no response from RAKP 3 message");
-		return 1;
+		lprintf(LOG_WARNING, "> Error: no response from RAKP 3 message");
+		return 2;
 	}
 
 
@@ -3333,8 +3359,8 @@ int
 ipmi_lanplus_open(struct ipmi_intf * intf)
 {
 	int rc;
+	int retry;
 	struct get_channel_auth_cap_rsp auth_cap;
-	struct sockaddr_in addr;
 	struct ipmi_session *session;
 
 	if (!intf || !intf->session)
@@ -3360,7 +3386,6 @@ ipmi_lanplus_open(struct ipmi_intf * intf)
 
 
 	/* Setup our lanplus session state */
-	session->v2_data.session_state    = LANPLUS_STATE_PRESESSION;
 	session->v2_data.auth_alg         = IPMI_AUTH_RAKP_NONE;
 	session->v2_data.crypt_alg        = IPMI_CRYPT_NONE;
 	session->v2_data.console_id       = 0x00;
@@ -3373,46 +3398,14 @@ ipmi_lanplus_open(struct ipmi_intf * intf)
 	/* Kg is set in ipmi_intf */
 	//memset(session->v2_data.kg,  0, IPMI_KG_BUFFER_SIZE);
 
-
-	/* open port to BMC */
-	memset(&addr, 0, sizeof(struct sockaddr_in));
-	addr.sin_family = AF_INET;
-	addr.sin_port = htons(session->port);
-
-	rc = inet_pton(AF_INET, (const char *)session->hostname, &addr.sin_addr);
-	if (rc <= 0) {
-		struct hostent *host = gethostbyname((const char *)session->hostname);
-		if (host == NULL) {
-			lprintf(LOG_ERR, "Address lookup for %s failed",
-				session->hostname);
-			return -1;
-		}
-		if (host->h_addrtype != AF_INET) {
-			lprintf(LOG_ERR,
-					"Address lookup for %s failed. Got %s, expected IPv4 address.",
-					session->hostname,
-					(host->h_addrtype == AF_INET6) ? "IPv6" : "Unknown");
-			return (-1);
-		}
-		addr.sin_family = host->h_addrtype;
-		memcpy(&addr.sin_addr, host->h_addr, host->h_length);
-	}
-
-	lprintf(LOG_DEBUG, "IPMI LAN host %s port %d",
-		session->hostname, ntohs(addr.sin_port));
-
-	intf->fd = socket(AF_INET, SOCK_DGRAM, IPPROTO_UDP);
-	if (intf->fd < 0) {
-		lperror(LOG_ERR, "Socket failed");
+	if (ipmi_intf_socket_connect (intf) == -1) {
+		lprintf(LOG_ERR, "Could not open socket!");
 		return -1;
 	}
 
-
-	/* connect to UDP socket so we get async errors */
-	rc = connect(intf->fd,
-				 (struct sockaddr *)&addr, sizeof(struct sockaddr_in));
-	if (rc < 0) {
-		lperror(LOG_ERR, "Connect failed");
+	if (intf->fd < 0) {
+		lperror(LOG_ERR, "Connect to %s failed",
+			session->hostname);
 		intf->close(intf);
 		return -1;
 	}
@@ -3436,43 +3429,61 @@ ipmi_lanplus_open(struct ipmi_intf * intf)
 		goto fail;
 	}
 
-
 	/*
-	 * Open session
+	 * If the open/rakp1/rakp3 sequence encounters a timeout, the whole sequence
+	 * needs to restart. The individual messages are not individually retryable,
+	 * as the session state is advancing.
 	 */
-	if (ipmi_lanplus_open_session(intf)){
-		intf->close(intf);
-		goto fail;
+	for (retry = 0; retry < IPMI_LAN_RETRY; retry++) {
+		session->v2_data.session_state = LANPLUS_STATE_PRESESSION;
+		/*
+		 * Open session
+		 */
+		if ((rc = ipmi_lanplus_open_session(intf)) == 1) {
+			intf->close(intf);
+			goto fail;
+		}
+		if (rc == 2) {
+			lprintf(LOG_DEBUG, "Retry lanplus open session, %d", retry);
+			continue;
+		}
+		/*
+		 * RAKP 1
+		 */
+		if ((rc = ipmi_lanplus_rakp1(intf)) == 1) {
+			intf->close(intf);
+			goto fail;
+		}
+		if (rc == 2) {
+			lprintf(LOG_DEBUG, "Retry lanplus rakp1, %d", retry);
+			continue;
+		}
+		/*
+		 * RAKP 3
+		 */
+		if ((rc = ipmi_lanplus_rakp3(intf)) == 1) {
+			intf->close(intf);
+			goto fail;
+		}
+		if (rc == 0) break;
+		lprintf(LOG_DEBUG,"Retry lanplus rakp3, %d", retry);
 	}
 
-	/*
-	 * RAKP 1
-	 */
-	if (ipmi_lanplus_rakp1(intf)){
-		intf->close(intf);
-		goto fail;
-	}
-
-
-	/*
-	 * RAKP 3
-	 */
-	if (ipmi_lanplus_rakp3(intf)){
-		intf->close(intf);
-		goto fail;
-	}
-
-
 	lprintf(LOG_DEBUG, "IPMIv2 / RMCP+ SESSION OPENED SUCCESSFULLY\n");
 
 	if (!ipmi_oem_active(intf, "i82571spt")) {
 		rc = ipmi_set_session_privlvl_cmd(intf);
-		if (rc < 0)
+		if (rc < 0) {
+			intf->close(intf);
 			goto fail;
+		}
 	}
 	intf->manufacturer_id = ipmi_get_oem(intf);
 	bridgePossible = 1;
 
+	/* automatically detect interface request and response sizes */
+	hpm2_detect_max_payload_size(intf);
+
 	return intf->fd;
 
  fail:
@@ -3624,5 +3635,46 @@ static int ipmi_lanplus_setup(struct ipmi_intf * intf)
 		return -1;
 	}
 	memset(intf->session, 0, sizeof(struct ipmi_session));
+
+    /* setup default LAN maximum request and response sizes */
+    intf->max_request_data_size = IPMI_LAN_MAX_REQUEST_SIZE;
+    intf->max_response_data_size = IPMI_LAN_MAX_RESPONSE_SIZE;
+
 	return 0;
 }
+
+static void ipmi_lanp_set_max_rq_data_size(struct ipmi_intf * intf, uint16_t size)
+{
+	if (intf->session->cipher_suite_id == 3) {
+		/*
+		 * encrypted payload can only be multiple of 16 bytes
+		 */
+		size &= ~15;
+
+		/*
+		 * decrement payload size on confidentiality header size
+		 * plus minimal confidentiality trailer size
+		 */
+		size -= (16 + 1);
+	}
+
+	intf->max_request_data_size = size;
+}
+
+static void ipmi_lanp_set_max_rp_data_size(struct ipmi_intf * intf, uint16_t size)
+{
+	if (intf->session->cipher_suite_id == 3) {
+		/*
+		 * encrypted payload can only be multiple of 16 bytes
+		 */
+		size &= ~15;
+
+		/*
+		 * decrement payload size on confidentiality header size
+		 * plus minimal confidentiality trailer size
+		 */
+		size -= (16 + 1);
+	}
+
+	intf->max_response_data_size = size;
+}
